window.Gleam.initSearch([{"doc":"plex_pin_auth","title":"plex_pin_auth","content":"# Plex Pin Authentication built with Gleam\n\n[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)\n[![Made with Gleam](https://img.shields.io/badge/Made%20with-Gleam-ffaff3.svg)](https://shields.io/)\n[![Status](https://img.shields.io/badge/Status-Completed-green.svg)](https://shields.io/)\n\n[![Package Version](https://img.shields.io/hexpm/v/plex_pin_auth)](https://hex.pm/packages/plex_pin_auth)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/plex_pin_auth/)\n\n## Scope\n\nThis project is linked to the project [plex_discord_rpc](https://github.com/harrisonhoward/plex_discord_rpc). The purpose of this project is to create a Gleam application that will authenticate with Plex using the pin authentication method. This will allow the user to authenticate with Plex and get the necessary token to make requests to the Plex API.\n\nSpecifically I created this to allow the user to authenticate themselves easily within the `plex_discord_rpc` tool, doing so allows the tool to connect to their Plex Media Server to connect to the WebSocket.\n\n## Usage\n\nThe method in which you handle getting a token is entirely left on the Developer. This an example of how you would create a pin and get the token.\n\nFeel free to use a package like [repeatedly](https://hexdocs.pm/repeatedly/) to handle the polling of the token.\n\n```gleam\nimport plex_pin_auth\nimport gleam/io\n\nconst my_client_id = &quot;YOUR_CLIENT_ID&quot;\n\npub fn main() {\n    // Creates the Plex pin\n    let assert Ok(pin) = plex_pin_auth.create_pin(client_id: my_client_id)\n    io.println(&quot;ID: &quot; &lt;&gt; pin.id)\n    io.println(&quot;Pin: &quot; &lt;&gt; pin.code)\n\n    // ... waiting for token\n\n    // Gets the token\n    let assert Ok(pin) = plex_pin_auth.get_token(my_client_id, pin.id)\n    let assert Some(token) = pin.auth_token\n    io.println(&quot;Token: &quot; &lt;&gt; token)\n}\n```\n\n## Plex Pin Auth Documentation\n\nIt appears the API isn&#39;t officially documented however I found some third-party documentation website. This website will be used in the creation of the pin authentication.\n\n- [get-pin](https://plexapi.dev/docs/plex/get-pin)\n- [get-token](https://plexapi.dev/docs/plex/get-token)\n\n## Contributing\n\n1. [Fork it](https://github.com/harrisonhoward/plex_pin_auth/fork)\n2. Clone your forked repository `git clone https://github.com/YOUR_USERNAME/plex_pin_auth.git`\n3. Create your feature branch `git checkout -b feature/my-new-feature`\n4. Commit your changes `git commit -am &#39;Add some feature&#39;`\n5. Push to the branch `git push origin feature/my-new-feature`\n6. Create a new Pull Request\n\n## Author\n\n[Harrison Howard](https://github.com/harrisonhoward)\n\n&gt; harrison.howard00707@gmail.com\n","url":"index.html"},{"doc":"plex_pin_auth/util/parser","title":"PlexError","content":"pub type PlexError {\n  PlexError(code: Int, message: String, status: Int)\n}\n Represents a single plex error that would be returned from the API\nPlexError(code: Int, message: String, status: Int)\n\n\nSynonyms:\nplex_pin_auth/util/parser.PlexError\nplex_pin_auth/util/parser PlexError","url":"plex_pin_auth/util/parser.html#PlexError"},{"doc":"plex_pin_auth/util/parser","title":"PlexLocation","content":"pub type PlexLocation {\n  PlexLocation(\n    code: String,\n    european_union_member: Bool,\n    continent_code: String,\n    country: String,\n    city: String,\n    time_zone: String,\n    postal_code: Option(String),\n    in_privacy_restricted_country: Bool,\n    subdivisions: String,\n    coordinates: String,\n  )\n}\n Represents the location object returns from get-pin API\nPlexLocation(\n  code: String,\n  european_union_member: Bool,\n  continent_code: String,\n  country: String,\n  city: String,\n  time_zone: String,\n  postal_code: Option(String),\n  in_privacy_restricted_country: Bool,\n  subdivisions: String,\n  coordinates: String,\n)\n\n\nSynonyms:\nplex_pin_auth/util/parser.PlexLocation\nplex_pin_auth/util/parser PlexLocation","url":"plex_pin_auth/util/parser.html#PlexLocation"},{"doc":"plex_pin_auth/util/parser","title":"PlexPin","content":"pub type PlexPin {\n  PlexPin(\n    id: Int,\n    code: String,\n    product: String,\n    trusted: Bool,\n    qr: String,\n    client_identifier: String,\n    location: PlexLocation,\n    expires_in: Int,\n    created_at: String,\n    expires_at: String,\n    auth_token: Option(String),\n    new_registration: Option(Bool),\n  )\n}\n Represents the object response from the get-pin API\nPlexPin(\n  id: Int,\n  code: String,\n  product: String,\n  trusted: Bool,\n  qr: String,\n  client_identifier: String,\n  location: PlexLocation,\n  expires_in: Int,\n  created_at: String,\n  expires_at: String,\n  auth_token: Option(String),\n  new_registration: Option(Bool),\n)\n\n\nSynonyms:\nplex_pin_auth/util/parser.PlexPin\nplex_pin_auth/util/parser PlexPin","url":"plex_pin_auth/util/parser.html#PlexPin"},{"doc":"plex_pin_auth/util/parser","title":"decode_error_json","content":"pub fn decode_error_json(\n  json_string: String,\n) -&gt; Result(PlexError, DecodeError)\n Returns a single PlexError from a JSON string that represents a list of PlexError\nSynonyms:\nplex_pin_auth/util/parser.decode_error_json\nplex_pin_auth/util/parser decode_error_json","url":"plex_pin_auth/util/parser.html#decode_error_json"},{"doc":"plex_pin_auth/util/parser","title":"decode_pin_json","content":"pub fn decode_pin_json(\n  json_string: String,\n) -&gt; Result(PlexPin, DecodeError)\n Returns a PlexPin from a JSON string that represents a PlexPin\nSynonyms:\nplex_pin_auth/util/parser.decode_pin_json\nplex_pin_auth/util/parser decode_pin_json","url":"plex_pin_auth/util/parser.html#decode_pin_json"},{"doc":"plex_pin_auth/util/parser","title":"plex_pin_auth/util/parser","content":" This module is for decoding JSON objects from HTTP requests. Designed specifically for the Plex API.","url":"plex_pin_auth/util/parser.html"},{"doc":"plex_pin_auth","title":"create_pin","content":"pub fn create_pin(\n  client_id client_identifier: String,\n) -&gt; Result(PlexPin, PlexError)\n Creates a Plex pin from the Plex API. Requires a client identifier.\nSynonyms:\nplex_pin_auth.create_pin\nplex_pin_auth create_pin","url":"plex_pin_auth.html#create_pin"},{"doc":"plex_pin_auth","title":"get_token","content":"pub fn get_token(\n  client_id client_identifier: String,\n  id pin_id: Int,\n) -&gt; Result(PlexPin, PlexError)\n Returns the Plex pin object from the Plex API. Requires a client identifier and the pin ID.\n \n If the Plex pin hasn&#39;t been linked (plex.tv/link) then the &#39;auth_token&#39; field will be empty.\nSynonyms:\nplex_pin_auth.get_token\nplex_pin_auth get_token","url":"plex_pin_auth.html#get_token"},{"doc":"plex_pin_auth","title":"plex_pin_auth","content":"","url":"plex_pin_auth.html"}]);